=======
History
=======

0.2.8 (2020-08-16)
------------------

- improved testing
- improved doc strings
- renamed some variables
  
0.2.7 (2019-03-27)
------------------

- improved description for better search results with "pip search pyhasse"
- moduel refactured based on pyhasse.core
  
0.2.6 (2019-03-24)
------------------

- URL for repository added

0.2.5 (2019-03-21)
------------------

- classifier added
- wrong pointer corrected


0.2.4 (2018-03-05)
------------------

- set long_description_content_type to text/x-rst


0.1.0 (2018-06-10)
------------------

* First version
